<?php
/**
 * filepress functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package filepress
 */

if ( ! function_exists( 'filepress_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function filepress_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on filepress, use a find and replace
	 * to change 'filepress' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'filepress', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
			'menu-main' => esc_html__( 'منوی اصلی', 'filepress' ),
			'menu-footer' => esc_html__( 'منوی فوتر', 'filepress' ),
			'menu-side' => esc_html__( 'منوی کنار', 'filepress' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'filepress_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	add_image_size( 'slide-show', 860, 280 );
	add_image_size( 'product-img', 250, 250 );
}
endif;
add_action( 'after_setup_theme', 'filepress_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function filepress_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'filepress_content_width', 640 );
}
add_action( 'after_setup_theme', 'filepress_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function filepress_widgets_init() {

	register_sidebar( 
		array(
		'name'          => esc_html__( 'کنار سایت', 'filepress' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'برای نمایش آخرین ها،برترین ها و...', 'filepress' ),
		'before_widget' => '<div id="%1$s" class="widget_wrapper  background_widget_wrapper shadow_contects_min  %2$s">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<div class="widget_title border_roman "><h3>',
		'after_title'   => '</h3></div> <div class="widget_content ">',
	) 
		);
}
add_action( 'widgets_init', 'filepress_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function filepress_scripts() {
	global $filepress;
	if($filepress['opt-font-name'] =='vazir' || !isset($filepress['opt-font-name']) || empty($filepress['opt-font-name']))
	{
		wp_enqueue_style( 'filepress-style-font', get_template_directory_uri().'/layouts/vazir.min.css' );

	}else
	{
		wp_enqueue_style( 'filepress-style-font', get_template_directory_uri().'/layouts/'.$filepress['opt-font-name'].'.min.css' );

	}
	wp_enqueue_style( 'filepress-style-bootstrap', get_template_directory_uri().'/layouts/bootstrap.min.css' );
	wp_enqueue_style( 'filepress-style-bootstrap-rtl', get_template_directory_uri().'/layouts/bootstrap-rtl.min.css' );
	wp_enqueue_style( 'filepress-font-awesome', get_template_directory_uri().'/layouts/font-awesome.min.css' );

	wp_enqueue_style( 'filepress-style', get_template_directory_uri().'/layouts/custom.css' );

	wp_enqueue_script( 'filepress-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'filepress-waypoints', get_template_directory_uri() . '/js/jquery.waypoints.min.js', array(), '20151215', true );
	wp_enqueue_script( 'filepress-vticker', get_template_directory_uri() . '/js/jquery.vticker.min.js', array(), '20151215', true );

	wp_enqueue_script( 'filepress-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'filepress-bootstrap-min', get_template_directory_uri() . '/js/bootstrap.min.js', array(), '20151215', true );
	wp_enqueue_script( 'filepress-custom-min', get_template_directory_uri() . '/js/custom.min.js', array('jquery'), time(), true );



	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'filepress_scripts' );

/**
 * Load css customiztion from user settings
 */
function filepress_custom_css()
{
	global $filepress;
	$css = '';

	if(isset($filepress['opt-site-main-color']) && !empty($filepress['opt-site-main-color']))
	{
		$main_color = $filepress['opt-site-main-color'];
		$css .= '
.online_store_header .online_store_logo_heder .icon_header_online_store a,
.online_store_main_content .soton_rast .latest_articles_wrapper .widget_content > ul li:hover p,
.online_store_main_content .soton_rast .support_wrapper .tell_Support,
body.single .online_store_main_content .soton_chap .widget_wrapper .widget_content .summary .product_list_widget li:hover::before,
body.single .online_store_main_content .soton_chap .widget_wrapper .widget_content .description .title_description > h3,
body.single .online_store_main_content .soton_chap .widget_wrapper .product_meta span a:hover,
body.single .online_store_main_content .soton_chap .woocommerce-tabs .comment-meta .comment-metadata a:hover,
body.single .online_store_main_content .soton_chap .woocommerce-tabs .reply a:hover,
.online_store_main_content .soton_chap .online_store_product .widget_title h2::before,
.online_store_main_content .soton_chap  .product:hover .price .woocommerce-Price-amount,
.online_store_main_content .soton_chap  .product:hover p,
.online_store_main_content .soton_chap  .widget_content .hovereffect .overlay p,
.online_store_main_content .soton_chap  .widget_content .hovereffect .overlay i,
.soton_rast .widget_content a:hover, .soton_rast .widget_content a:active, .soton_rast .widget_content a:focus,
.online_store_main_content .article_content a:hover
{
    color: '.$main_color.';
}

.online_store_main_content .soton_rast .news_wrapper .c-newsletter-send,
.online_store_main_content .soton_rast .send_ticket_wrapper .widget_content .send_ticketr-send,
body.single .online_store_main_content .soton_chap .widget_wrapper .widget_content .summary .btn_etelat .single_cart_button,
body.single .online_store_main_content .soton_chap .widget_wrapper .widget_content .message_successful,
body.single .online_store_main_content .soton_chap .woocommerce-Tabs-panel .woocommerce-Reviews #review_form_wrapper .comment-form .form-submit .submit,
.online_store_main_content .soton_chap  .product .edame_matlab
{
    background:   '.$main_color.' none repeat scroll 0 0;
}


.online_store_main_menu .online_store_main_menu_navbar #top-menu > li:nth-child(odd):before,
.menu-item .dropdown-menu > li:nth-child(odd):before,
.online_store_main_content .soton_rast .meno_right_wrapper .widget_content .sidebar-nav li:nth-child(odd):before,
.online_store_main_content .soton_chap .carousel_wrapper .carousel-indicators li,
.online_store_main_menu_navbar .navbar-toggle,
.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .border_top,
.borobala,
.online_store_main_content .soton_rast .widget_wrapper.filepress_widget_support_ticket.send_ticket_wrapper .widget_content,
.edd-submit.blue.button, .soton_rast input[type="button"], .soton_rast input[type="submit"] ,
.online_store_main_content .widget_footer .btn.btn-default.edameh_btn
{
    background-color:  '.$main_color.';
}

body.single .online_store_main_content .soton_chap .woocommerce-tabs .byuser .comment-body .comment-meta .avatar,
.online_store_main_content .soton_chap  .product:hover
{
    border-color:  '.$main_color.';
}

::selection {
    background: '.$main_color.';
    /* WebKit/Blink Browsers */
    color: #fff;
}

::-moz-selection {
    background: '.$main_color.';
    /* Gecko Browsers */
    color: #fff;
}

body.single .online_store_main_content .soton_chap .woocommerce-tabs .byuser .comment-content {
	background-color: '.filepress_adjustBrightness($main_color,200).';
}
';

	}
	if(isset($filepress['opt-site-second-color']) && !empty($filepress['opt-site-second-color']))
	{
		$second_color = $filepress['opt-site-second-color'];
		$css .= '
		.online_store_header .online_store_logo_heder .icon_header_online_store a:hover,
		.online_store_main_menu .collapse .navbar-left > li > a:hover,
		.online_store_main_menu .collapse .navbar-left > li > a:focus,
		.online_storenew_news_bar .new-news-bar,
		.online_store_main_content .soton_rast .latest_articles_wrapper .widget_content > ul li:hover .time_meta,
		.online_store_main_content .soton_rast .support_wrapper .tell_Support i,
		.online_store_main_content .soton_chap .carousel_wrapper .carousel-control span,
		body.single .online_store_main_content .soton_chap .widget_wrapper .widget_content .summary .product_list_widget li:hover,
		.online_store_main_content .soton_chap  .product .interested:hover,
		.online_store_main_content .soton_chap  .product:hover .price p del
		{
		    color: '.$second_color.';
		}
		
		.online_store_header .shop_cart_item_counter,.borobala::before
		{
		    background: '.$second_color.';
		}
		.edd-submit.blue.button:focus, .edd-submit.blue.button:hover, .edd-submit.blue.button:active, .soton_rast input[type="button"]:focus, .soton_rast input[type="button"]:active, .soton_rast input[type="button"]:hover, .soton_rast input[type="submit"]:focus, .soton_rast input[type="submit"]:active, .soton_rast input[type="submit"]:hover {
			background-color: '.$second_color.';

		}

		.online_store_main_content .widget_footer .btn.btn-default.edameh_btn:hover {
			box-shadow: -100px 0 0 '.$second_color.' inset;
		}


		.online_store_main_menu .online_store_main_menu_navbar #top-menu > li:nth-child(even):before,
		.menu-item .dropdown-menu > li:nth-child(even):before,
		.online_store_main_content .soton_rast .meno_right_wrapper .widget_content .sidebar-nav li:nth-child(even):before,
		.online_store_main_content .soton_chap .carousel_wrapper .carousel-indicators .active,
		.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .border_right,
		.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .fix_left .pagination > li > span:hover,
		.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .fix_left .pagination > li > span:focus,
		.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .fix_left .pagination.current.active,
		.online_store_main_content .soton_rast .widget_wrapper.filepress_widget_support_ticket.send_ticket_wrapper .widget_content:hover
		{
		    background-color: '.$second_color.';
		}
		
		.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .fix_left .pagination > li > span:hover,
		.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .fix_left .pagination > li > span:focus,
		.online_store_main_content .soton_chap .catalogs_slider_wrapper .widget_title .fix_left .pagination.current.active
		{
		    border-color: '.$second_color.';
		}
		
		.online_store_main_content .soton_rast .news_wrapper .c-newsletter-send,
		.online_store_main_content .soton_rast .send_ticket_wrapper .widget_content .send_ticketr-send,
		body.single .online_store_main_content .soton_chap .widget_wrapper .widget_content .summary .btn_etelat .single_cart_button,
		body.single .online_store_main_content .soton_chap .woocommerce-Tabs-panel .woocommerce-Reviews #review_form_wrapper .comment-form .form-submit .submit,
		.online_store_main_content .soton_chap  .product .edame_matlab
		{
		    box-shadow: 0 0 0 '.$second_color.' inset;
		}

		/*.online_store_main_content .soton_rast .send_ticket_wrapper .widget_content .send_ticketr-send:hover {
			box-shadow: -800px 0 0 '.$second_color.' inset;
		}*/
		.online_store_main_content .soton_chap  .product .edame_matlab:hover,
		.online_store_main_content .soton_rast .news_wrapper .c-newsletter-send:hover {
		    box-shadow: -100px 0 0 '.$second_color.' inset;
		}
		body.single .online_store_main_content .soton_chap .widget_wrapper .widget_content .summary .btn_etelat .single_cart_button:hover {
		    box-shadow: -350px 0 0 '.$second_color.' inset;
		}
		body.single .online_store_main_content .soton_chap .woocommerce-Tabs-panel .woocommerce-Reviews #review_form_wrapper .comment-form .form-submit .submit:hover {
		    box-shadow: -100px 0 0 '.$second_color.' inset;
		}
	.online_store_main_content .soton_rast .widget_wrapper.filepress_widget_support_ticket.send_ticket_wrapper .widget_content:hover {
		box-shadow: -800px 0 0 '.$second_color.' inset;
	}
		';
	}

	if(!empty($css))
	{
		echo '<style>';
		echo str_replace(array("\n"), '', $css);
		echo '</style>';
	}
}

add_action( 'wp_head', 'filepress_custom_css' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * theme-options
 */
require get_template_directory() . '/inc/theme-options.php';


/**
 * Needed Plugins
 */
require get_template_directory() . '/inc/needed_plugins.php';

/**
 * Needed Plugins
 */
require get_template_directory() . '/inc/wp_bootstrap_navwalker.php';
/**
 * Widgets
 */
require get_template_directory() . '/inc/widgets.php';

/**
 * Post types
 */
require get_template_directory() . '/inc/post-types.php';

/**
 * Post meta
 */
require get_template_directory() . '/inc/post-meta.php';

/**
 * License
 */
require get_template_directory() . '/lic.php';

